@@ -27,11 +27,12 @@ from emannotationschemas.schemas.derived_spatial_point import (
 from emannotationschemas.schemas.proofreading import (
     CompartmentProofreadStatus,
     ProofreadStatus,
+    ProofreadingBoolStatusUser,
 )
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "3.3.0"
+__version__ = "3.4.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -55,6 +56,7 @@ type_mapping = {
     "derived_numeric_value": DerivedNumeric,
     "proofread_status": ProofreadStatus,
     "compartment_proofread_status": CompartmentProofreadStatus,
+    "proofreading_boolstatus_user": ProofreadingBoolStatusUser,
 }
 
 
